within ;
package MOS4



  model HeartElasticity

    Modelica.Blocks.Interfaces.RealInput Tsyst "dlka systoly" annotation (Placement(
          transformation(extent={{-120,12},{-80,52}}), iconTransformation(extent={{-126,62},
              {-100,88}})));
    Modelica.Blocks.Interfaces.RealOutput Et "elasticita (torr/ml)" annotation (Placement(
          transformation(extent={{94,16},{114,36}}), iconTransformation(extent={{100,20},
              {120,40}})));
    Modelica.Blocks.Interfaces.RealInput Esys
      "maximln (systolick) elesticita (torr/ml)"                                         annotation (Placement(
          transformation(extent={{-120,12},{-80,52}}), iconTransformation(extent={{-126,
              -22},{-100,4}})));
    Modelica.Blocks.Interfaces.RealInput Edias
      "minimln (diastolick) elasticita (torr/ml)"                                          annotation (Placement(
          transformation(extent={{-120,12},{-80,52}}), iconTransformation(extent={{-126,
              -64},{-100,-38}})));
    Modelica.Blocks.Interfaces.RealInput T0 "cas poctku systoly"   annotation (Placement(
          transformation(extent={{-120,12},{-80,52}}), iconTransformation(extent={{-126,18},
              {-100,44}})));
  equation

    Et = if (time - T0 >= 0 and time - T0 <= Tsyst) then Edias + (Esys - Edias)
      /2*(1 - cos(Modelica.Constants.pi*(time - T0)/Tsyst)) else if (time - T0
       < (3/2)*Tsyst) then Edias + (Esys - Edias)/2*(1 + cos(2*Modelica.Constants.pi
      *(time - T0 - Tsyst)/Tsyst)) else Edias;
    annotation (Icon(graphics={
          Rectangle(extent={{-100,100},{100,-100}}, lineColor={0,0,255}),
          Text(
            extent={{-100,122},{100,100}},
            lineColor={0,0,255},
            textString="Heart Elasticity"),
          Text(
            extent={{-114,36},{-42,24}},
            lineColor={0,0,255},
            textString="T0"),
          Text(
            extent={{-112,82},{-40,70}},
            lineColor={0,0,255},
            textString="Tsyst"),
          Text(
            extent={{-114,-4},{-42,-16}},
            lineColor={0,0,255},
            textString="Esys"),
          Text(
            extent={{-114,-44},{-38,-56}},
            lineColor={0,0,255},
            textString="Edias"),
          Text(
            extent={{56,36},{124,24}},
            lineColor={0,0,255},
            textString="Et"),
          Bitmap(extent={{-88,100},{112,-100}}, fileName=
                "modelica://MOS4/ICONS/elasticitaSrdce.png")}));
  end HeartElasticity;



  connector PressureFlow "Pressure[mmHg] and Flow[ml/min]"
    Real pressure( final quantity="Pressure", final unit="mmHg");
    flow Real q( final quantity="Flow", final unit="ml/min") "flow";
    annotation (Documentation(revisions="<html>
<table>
<tr>
<td>Author:</td>
<td>Marek Matejak</td>
</tr>
<tr>
<td>Copyright:</td>
<td>In public domains</td>
</tr>
<tr>
<td>By:</td>
<td>Charles University, Prague, Czech Republic</td>
</tr>
<tr>
<td>Date of:</td>
<td>january 2009</td>
</tr>
</table>
</html>",
      info="<html>
<p><font style=\"font-size: 9pt; \">This connector connects hydraulic domains elements. The elements contains one equation for each his pressure-flow connector. The equation defines relation between variables in the connector. Variables are hydraulic pressure and volume flow of hydraulic medium. The pressure is the same in each connector that are connected together. The sum of flow in connectors connected together is zero (</font><b><font style=\"font-size: 9pt; \">Kirchhoff&apos;s circuit laws</font></b><font style=\"font-size: 9pt; \">).</font> </p>
</html>"));
  end PressureFlow;

  connector NegativePressureFlow "Pressure[mmHg] and negative Outflow[ml/min]"

    extends PressureFlow;

  annotation (
      defaultComponentName="q_out",
      Icon(coordinateSystem(preserveAspectRatio=true, extent={{-100,-100},{
              100,100}}), graphics={Rectangle(
            extent={{-20,10},{20,-10}},
            lineColor={0,0,0},
            lineThickness=1), Polygon(
            points={{0,100},{100,0},{0,-100},{-100,0},{0,100}},
            lineColor={0,0,0},
            smooth=Smooth.None,
            fillPattern=FillPattern.Solid,
            fillColor={200,200,200})}),
      Diagram(Polygon(points=[-21,-3; 5,23; 31,-3; 5,-29; -21,-3],   style(
            color=74,
            rgbcolor={0,0,0},
            fillColor=0,
            rgbfillColor={0,0,0})), Text(
          extent=[-105,-38; 115,-83],
          string="%name",
          style(color=0, rgbcolor={0,0,0}))));
  end NegativePressureFlow;

  connector PositivePressureFlow "Pressure[mmHg] and Inflow[ml/min]"
    extends PressureFlow;

  annotation (
      defaultComponentName="q_in",
      Icon(coordinateSystem(preserveAspectRatio=true, extent={{-100,-100},{
              100,100}}), graphics={Rectangle(
            extent={{-20,10},{20,-10}},
            lineColor={0,0,0},
            lineThickness=1), Polygon(
            points={{0,100},{100,0},{0,-100},{-100,0},{0,100}},
            lineColor={0,0,0},
            smooth=Smooth.None,
            fillPattern=FillPattern.Solid,
            fillColor={0,0,0})}),
      Diagram(Polygon(points=[-21,-3; 5,23; 31,-3; 5,-29; -21,-3],   style(
            color=74,
            rgbcolor={0,0,0},
            fillColor=0,
            rgbfillColor={0,0,0})), Text(
          extent=[-105,-38; 115,-83],
          string="%name",
          style(color=0, rgbcolor={0,0,0}))));
  end PositivePressureFlow;


  annotation (uses(Modelica(version="3.2")));
  model TestHeartElasticity
    HeartElasticity heartElasticity
      annotation (Placement(transformation(extent={{60,0},{80,20}})));
    Modelica.Blocks.Sources.Constant Tsyst(k=0.27)
      annotation (Placement(transformation(extent={{-80,8},{-60,28}})));
    Modelica.Blocks.Sources.Constant T0(k=0.83)
      annotation (Placement(transformation(extent={{-60,-20},{-40,0}})));
    Modelica.Blocks.Sources.Constant const(k=1)
      annotation (Placement(transformation(extent={{-40,-50},{-20,-30}})));
    Modelica.Blocks.Math.Gain LEsys0(k=1/0.4)
      annotation (Placement(transformation(extent={{0,-20},{20,0}})));
    Modelica.Blocks.Math.Gain LEdias0(k=1/10)
      annotation (Placement(transformation(extent={{20,-40},{40,-20}})));
  equation
    connect(Tsyst.y, heartElasticity.Tsyst) annotation (Line(
        points={{-59,18},{-9.35,18},{-9.35,17.3},{60.3,17.3}},
        color={0,0,127},
        smooth=Smooth.None));
    connect(T0.y, heartElasticity.T0) annotation (Line(
        points={{-39,-10},{-34,-10},{-34,13.1},{60.3,13.1}},
        color={0,0,127},
        smooth=Smooth.None));
    connect(const.y, LEsys0.u) annotation (Line(
        points={{-19,-40},{-10,-40},{-10,-10},{-2,-10}},
        color={0,0,127},
        smooth=Smooth.None));
    connect(const.y, LEdias0.u) annotation (Line(
        points={{-19,-40},{10,-40},{10,-30},{18,-30}},
        color={0,0,127},
        smooth=Smooth.None));
    connect(LEsys0.y, heartElasticity.Esys) annotation (Line(
        points={{21,-10},{40,-10},{40,9.1},{60.1,9.1}},
        color={0,0,127},
        smooth=Smooth.None));
    connect(LEdias0.y, heartElasticity.Edias) annotation (Line(
        points={{41,-30},{50,-30},{50,4.9},{60.3,4.9}},
        color={0,0,127},
        smooth=Smooth.None));
    annotation (Diagram(graphics={Rectangle(extent={{-84,58},{-22,-24}},
              lineColor={0,0,255}), Text(
            extent={{-72,48},{-34,44}},
            lineColor={0,0,255},
            textString="HeartIntervals za domaci ukol")}));
  end TestHeartElasticity;
end MOS4;
